@@ -1588,6 +1588,41 @@ class KeyPurposeId(ObjectIdentifier):
         '1.3.6.1.4.1.311.10.3.12': 'microsoft_document_signing',
         '1.3.6.1.4.1.311.10.3.13': 'microsoft_lifetime_signing',
         '1.3.6.1.4.1.311.10.3.14': 'microsoft_mobile_device_software',
+        # https://opensource.apple.com/source
+        #  - /Security/Security-57031.40.6/Security/libsecurity_keychain/lib/SecPolicy.cpp
+        #  - /libsecurity_cssm/libsecurity_cssm-36064/lib/oidsalg.c
+        '1.2.840.113635.100.1.2': 'apple_x509_basic',
+        '1.2.840.113635.100.1.3': 'apple_ssl',
+        '1.2.840.113635.100.1.4': 'apple_local_cert_gen',
+        '1.2.840.113635.100.1.5': 'apple_csr_gen',
+        '1.2.840.113635.100.1.6': 'apple_revocation_crl',
+        '1.2.840.113635.100.1.7': 'apple_revocation_ocsp',
+        '1.2.840.113635.100.1.8': 'apple_smime',
+        '1.2.840.113635.100.1.9': 'apple_eap',
+        '1.2.840.113635.100.1.10': 'apple_software_update_signing',
+        '1.2.840.113635.100.1.11': 'apple_ipsec',
+        '1.2.840.113635.100.1.12': 'apple_ichat',
+        '1.2.840.113635.100.1.13': 'apple_resource_signing',
+        '1.2.840.113635.100.1.14': 'apple_pkinit_client',
+        '1.2.840.113635.100.1.15': 'apple_pkinit_server',
+        '1.2.840.113635.100.1.16': 'apple_code_signing',
+        '1.2.840.113635.100.1.17': 'apple_package_signing',
+        '1.2.840.113635.100.1.18': 'apple_id_validation',
+        '1.2.840.113635.100.1.20': 'apple_time_stamping',
+        '1.2.840.113635.100.1.21': 'apple_revocation',
+        '1.2.840.113635.100.1.22': 'apple_passbook_signing',
+        '1.2.840.113635.100.1.23': 'apple_mobile_store',
+        '1.2.840.113635.100.1.24': 'apple_escrow_service',
+        '1.2.840.113635.100.1.25': 'apple_profile_signer',
+        '1.2.840.113635.100.1.26': 'apple_qa_profile_signer',
+        '1.2.840.113635.100.1.27': 'apple_test_mobile_store',
+        '1.2.840.113635.100.1.28': 'apple_otapki_signer',
+        '1.2.840.113635.100.1.29': 'apple_test_otapki_signer',
+        '1.2.840.113625.100.1.30': 'apple_id_validation_record_signing_policy',
+        '1.2.840.113625.100.1.31': 'apple_smp_encryption',
+        '1.2.840.113625.100.1.32': 'apple_test_smp_encryption',
+        '1.2.840.113635.100.1.33': 'apple_server_authentication',
+        '1.2.840.113635.100.1.34': 'apple_pcs_escrow_service',
     }
 
 
@@ -1873,8 +1908,8 @@ class Certificate(Sequence):
             None or an x509.GeneralNames object
         """
 
-        if self._processed_extensions is False:
-            self._processed_extensions()
+        if not self._processed_extensions:
+            self._set_extensions()
         return self._issuer_alt_name_value
 
     @property
